@@ -4,7 +4,7 @@ use warnings;
 
 package App::perlzonji::Plugin::SpecialPackages;
 BEGIN {
-  $App::perlzonji::Plugin::SpecialPackages::VERSION = '1.101420';
+  $App::perlzonji::Plugin::SpecialPackages::VERSION = '1.101610';
 }
 
 # ABSTRACT: Plugin to find documentation for special Perl packages
@@ -28,7 +28,7 @@ App::perlzonji::Plugin::SpecialPackages - Plugin to find documentation for speci
 
 =head1 VERSION
 
-version 1.101420
+version 1.101610
 
 =head1 SYNOPSIS
 
@@ -49,7 +49,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=App-perlzonji>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
